Index: src/Fl_Menu_.cxx
===================================================================
--- src/Fl_Menu_.cxx	(revision 10505)
+++ src/Fl_Menu_.cxx	(working copy)
@@ -255,7 +255,7 @@
     if (v->radio()) {
       if (!v->value()) { // they are turning on a radio item
 	set_changed();
-	((Fl_Menu_Item*)v)->setonly();
+	setonly((Fl_Menu_Item*)v);
       }
       redraw();
     } else if (v->flags & FL_MENU_TOGGLE) {
@@ -276,7 +276,10 @@
   return v;
 }

-/** Turns the radio item "on" for the menu item and turns off adjacent radio items set. */
+/** Turns the radio item "on" for the menu item and turns off adjacent radio items set.
+    Deprecated: this method is dangerous if radio items are first in the menu.
+    Use Fl_Menu_::setonly(Fl_Menu_Item*) instead.
+ */
 void Fl_Menu_Item::setonly() {
   flags |= FL_MENU_RADIO | FL_MENU_VALUE;
   Fl_Menu_Item* j;
@@ -292,6 +295,23 @@
   }
 }

+/** Turns the radio item "on" for the menu item and turns off adjacent radio items set. */
+void Fl_Menu_::setonly(Fl_Menu_Item* item) {
+  item->flags |= FL_MENU_RADIO | FL_MENU_VALUE;
+  Fl_Menu_Item* j;
+  for (j = item; ; ) {	// go down
+    if (j->flags & FL_MENU_DIVIDER) break; // stop on divider lines
+    j++;
+    if (!j->text || !j->radio()) break; // stop after group
+    j->clear();
+  }
+  for (j = item-1; j>=menu_; j--) { // go up
+    //DEBUG printf("GO UP: WORKING ON: item='%s', flags=%x\n", j->text, j->flags);
+    if (!j->text || (j->flags&FL_MENU_DIVIDER) || !j->radio()) break;
+    j->clear();
+  }
+}
+
 /**
  Creates a new Fl_Menu_ widget using the given position, size,
  and label string.  menu() is initialized to null.
